summaryrefslogtreecommitdiff
path: root/plugingui/plugingui.cc
diff options
context:
space:
mode:
Diffstat (limited to 'plugingui/plugingui.cc')
-rw-r--r--plugingui/plugingui.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/plugingui/plugingui.cc b/plugingui/plugingui.cc
index 262b34b..babc530 100644
--- a/plugingui/plugingui.cc
+++ b/plugingui/plugingui.cc
@@ -8,20 +8,20 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
#include "plugingui.h"
@@ -261,10 +261,10 @@ void PluginGUI::init()
(void*)&closing);
window->setFixedSize(370, 330);
- window->setCaption("DrumGizmo v" VERSION);
+ window->setCaption("CamSync v" VERSION);
Label *lbl_title = new Label(window);
- lbl_title->setText("DrumGizmo");
+ lbl_title->setText("CamSync");
lbl_title->move(127, 7);
lbl_title->resize(200, 20);
@@ -389,7 +389,7 @@ void PluginGUI::init()
l2->resize(window->width() - 40, 2);
Label *lbl_version = new Label(window);
- lbl_version->setText(".::. v" VERSION " .::. http://www.drumgizmo.org .::. GPLv3 .::.");
+ lbl_version->setText(".::. v" VERSION " .::. http://www.camsync.org .::. GPLv3 .::.");
lbl_version->move(16, 300);
lbl_version->resize(window->width(), 20);
/*
@@ -8,20 +8,20 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,20 +8,20 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,20 +8,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/